from __future__ import absolute_import, division, print_function

import stripe


class TestBalance(object):
    def test_is_retrievable(self, request_mock):
        resource = stripe.Balance.retrieve()
        request_mock.assert_requested(
            'get',
            '/v1/balance'
        )
        assert isinstance(resource, stripe.Balance)



from __future__ import absolute_import, division, print_function

import stripe


TEST_RESOURCE_ID = 'loc_123'


class TestLocation(object):
    def test_is_creatable(self, request_mock):
        resource = stripe.terminal.Location.create(
            display_name='name',
            address={
                'line1': 'line1',
                'country': 'US',
                'state': 'CA',
                'postal_code': '12345',
                'city': 'San Francisco',
            }
        )
        request_mock.assert_requested(
            'post',
            '/v1/terminal/locations'
        )
        assert isinstance(resource, stripe.terminal.Location)

    def test_is_listable(self, request_mock):
        resources = stripe.terminal.Location.list()
        request_mock.assert_requested(
            'get',
            '/v1/terminal/locations'
        )
        assert isinstance(resources.data, list)
        assert isinstance(resources.data[0], stripe.terminal.Location)

    def test_is_modifiable(self, request_mock):
        resource = stripe.terminal.Location.modify(
            TEST_RESOURCE_ID,
            display_name='new-name'
        )
        request_mock.assert_requested(
            'post',
            '/v1/terminal/locations/%s' % TEST_RESOURCE_ID
        )
        assert isinstance(resource, stripe.terminal.Location)

    def test_is_retrievable(self, request_mock):
        resource = stripe.terminal.Location.retrieve(TEST_RESOURCE_ID)
        request_mock.assert_requested(
            'get',
            '/v1/terminal/locations/%s' % TEST_RESOURCE_ID
        )
        assert isinstance(resource, stripe.terminal.Location)

    def test_is_saveable(self, request_mock):
        resource = stripe.terminal.Location.retrieve(TEST_RESOURCE_ID)
        resource.display_name = 'new-name'
        location = resource.save()
        request_mock.assert_requested(
            'post',
            '/v1/terminal/locations/%s' % TEST_RESOURCE_ID
        )
        assert isinstance(resource, stripe.terminal.Location)
        assert resource is location



from __future__ import absolute_import, division, print_function

import stripe


TEST_RESOURCE_ID = 'ich_123'


class TestCardholder(object):
    def test_is_creatable(self, request_mock):
        resource = stripe.issuing.Cardholder.create(
            billing={
                'address': {
                    'city': 'city',
                    'country': 'US',
                    'line1': 'line1',
                    'postal_code': 'postal_code',
                },
            },
            name='Jenny Rosen',
            type='individual'
        )
        request_mock.assert_requested(
            'post',
            '/v1/issuing/cardholders'
        )
        assert isinstance(resource, stripe.issuing.Cardholder)

    def test_is_listable(self, request_mock):
        resources = stripe.issuing.Cardholder.list()
        request_mock.assert_requested(
            'get',
            '/v1/issuing/cardholders'
        )
        assert isinstance(resources.data, list)
        assert isinstance(resources.data[0], stripe.issuing.Cardholder)

    def test_is_modifiable(self, request_mock):
        resource = stripe.issuing.Cardholder.modify(
            TEST_RESOURCE_ID,
            metadata={'key': 'value'}
        )
        request_mock.assert_requested(
            'post',
            '/v1/issuing/cardholders/%s' % TEST_RESOURCE_ID
        )
        assert isinstance(resource, stripe.issuing.Cardholder)

    def test_is_retrievable(self, request_mock):
        resource = stripe.issuing.Cardholder.retrieve(TEST_RESOURCE_ID)
        request_mock.assert_requested(
            'get',
            '/v1/issuing/cardholders/%s' % TEST_RESOURCE_ID
        )
        assert isinstance(resource, stripe.issuing.Cardholder)

    def test_is_saveable(self, request_mock):
        resource = stripe.issuing.Cardholder.retrieve(TEST_RESOURCE_ID)
        resource.metadata['key'] = 'value'
        cardholder = resource.save()
        request_mock.assert_requested(
            'post',
            '/v1/issuing/cardholders/%s' % TEST_RESOURCE_ID
        )
        assert isinstance(resource, stripe.issuing.Cardholder)
        assert resource is cardholder



from __future__ import absolute_import, division, print_function

import stripe


TEST_RESOURCE_ID = 'rsli_123'


class TestValueListItem(object):
    def test_is_listable(self, request_mock):
        resources = stripe.radar.ValueListItem.list(value_list='rsl_123')
        request_mock.assert_requested(
            'get',
            '/v1/radar/value_list_items'
        )
        assert isinstance(resources.data, list)
        assert isinstance(resources.data[0], stripe.radar.ValueListItem)

    def test_is_retrievable(self, request_mock):
        resource = stripe.radar.ValueListItem.retrieve(TEST_RESOURCE_ID)
        request_mock.assert_requested(
            'get',
            '/v1/radar/value_list_items/%s' % TEST_RESOURCE_ID
        )
        assert isinstance(resource, stripe.radar.ValueListItem)

    def test_is_creatable(self, request_mock):
        resource = stripe.radar.ValueListItem.create(
          value_list='rsl_123',
          value='value'
        )
        request_mock.assert_requested(
            'post',
            '/v1/radar/value_list_items'
        )
        assert isinstance(resource, stripe.radar.ValueListItem)

    def test_is_deletable(self, request_mock):
        resource = stripe.radar.ValueListItem.retrieve(TEST_RESOURCE_ID)
        resource.delete()
        request_mock.assert_requested(
            'delete',
            '/v1/radar/value_list_items/%s' % TEST_RESOURCE_ID
        )
        assert resource.deleted is True



from __future__ import absolute_import, division, print_function

import pytest

import stripe


TEST_RESOURCE_ID = 'trr_123'


class TestPerson(object):
    def construct_resource(self):
        person_dict = {
            'id': TEST_RESOURCE_ID,
            'object': 'person',
            'account': 'acct_123'
        }
        return stripe.Person.construct_from(person_dict, stripe.api_key)

    def test_has_instance_url(self, request_mock):
        resource = self.construct_resource()
        assert resource.instance_url() == \
            '/v1/accounts/acct_123/persons/%s' % TEST_RESOURCE_ID

    def test_is_not_modifiable(self, request_mock):
        with pytest.raises(NotImplementedError):
            stripe.Person.modify(
                TEST_RESOURCE_ID,
                first_name='John'
            )

    def test_is_not_retrievable(self, request_mock):
        with pytest.raises(NotImplementedError):
            stripe.Person.retrieve(TEST_RESOURCE_ID)

    def test_is_saveable(self, request_mock):
        resource = self.construct_resource()
        resource.first_name = 'John'
        resource.save()
        request_mock.assert_requested(
            'post',
            '/v1/accounts/acct_123/persons/%s' % TEST_RESOURCE_ID
        )



from __future__ import absolute_import, division, print_function

import stripe


TEST_RESOURCE_ID = 'rsl_123'


class TestValueList(object):
    def test_is_listable(self, request_mock):
        resources = stripe.radar.ValueList.list()
        request_mock.assert_requested(
            'get',
            '/v1/radar/value_lists'
        )
        assert isinstance(resources.data, list)
        assert isinstance(resources.data[0], stripe.radar.ValueList)

    def test_is_retrievable(self, request_mock):
        resource = stripe.radar.ValueList.retrieve(TEST_RESOURCE_ID)
        request_mock.assert_requested(
            'get',
            '/v1/radar/value_lists/%s' % TEST_RESOURCE_ID
        )
        assert isinstance(resource, stripe.radar.ValueList)

    def test_is_creatable(self, request_mock):
        resource = stripe.radar.ValueList.create(
          alias='alias',
          name='name'
        )
        request_mock.assert_requested(
            'post',
            '/v1/radar/value_lists'
        )
        assert isinstance(resource, stripe.radar.ValueList)

    def test_is_saveable(self, request_mock):
        resource = stripe.radar.ValueList.retrieve(TEST_RESOURCE_ID)
        resource.metadata['key'] = 'value'
        resource.save()
        request_mock.assert_requested(
            'post',
            '/v1/radar/value_lists/%s' % TEST_RESOURCE_ID
        )

    def test_is_modifiable(self, request_mock):
        resource = stripe.radar.ValueList.modify(
            TEST_RESOURCE_ID,
            metadata={'key': 'value'}
        )
        request_mock.assert_requested(
            'post',
            '/v1/radar/value_lists/%s' % TEST_RESOURCE_ID
        )
        assert isinstance(resource, stripe.radar.ValueList)

    def test_is_deletable(self, request_mock):
        resource = stripe.radar.ValueList.retrieve(TEST_RESOURCE_ID)
        resource.delete()
        request_mock.assert_requested(
            'delete',
            '/v1/radar/value_lists/%s' % TEST_RESOURCE_ID
        )
        assert resource.deleted is True



from __future__ import absolute_import, division, print_function

import tempfile

import pytest

import stripe


TEST_RESOURCE_ID = 'file_123'


class TestFile(object):
    @pytest.fixture(scope='function')
    def setup_upload_api_base(self):
        stripe.upload_api_base = stripe.api_base
        stripe.api_base = None
        yield
        stripe.api_base = stripe.upload_api_base
        stripe.upload_api_base = 'https://files.stripe.com'

    def test_is_listable(self, request_mock):
        resources = stripe.File.list()
        request_mock.assert_requested(
            'get',
            '/v1/files'
        )
        assert isinstance(resources.data, list)
        assert isinstance(resources.data[0], stripe.File)

    def test_is_retrievable(self, request_mock):
        resource = stripe.File.retrieve(TEST_RESOURCE_ID)
        request_mock.assert_requested(
            'get',
            '/v1/files/%s' % TEST_RESOURCE_ID
        )
        assert isinstance(resource, stripe.File)

    def test_is_creatable(self, setup_upload_api_base, request_mock):
        stripe.multipart_data_generator.MultipartDataGenerator\
            ._initialize_boundary = lambda self: 1234567890
        test_file = tempfile.TemporaryFile()
        resource = stripe.File.create(
            purpose='dispute_evidence',
            file=test_file
        )
        request_mock.assert_api_base(stripe.upload_api_base)
        request_mock.assert_requested(
            'post',
            '/v1/files',
            headers={
                'Content-Type': 'multipart/form-data; boundary=1234567890',
            }
        )
        assert isinstance(resource, stripe.File)

    def test_deserializes_from_file(self):
        obj = stripe.util.convert_to_stripe_object({
            'object': 'file',
        })
        assert isinstance(obj, stripe.File)

    def test_deserializes_from_file_upload(self):
        obj = stripe.util.convert_to_stripe_object({
            'object': 'file_upload',
        })
        assert isinstance(obj, stripe.File)
